AgsiGeometryAreaFromLines

Enum AgsiGeometryAreaFromLines 

pub enum AgsiGeometryAreaFromLines {
    Variant0 {
        agsi_geometry_top: AgsiGeometryFromFile,
        description: Option<String>,
        geometry_id: Option<String>,
        remarks: Option<String>,
    },
    Variant1 {
        agsi_geometry_bottom: AgsiGeometryFromFile,
        description: Option<String>,
        geometry_id: Option<String>,
        remarks: Option<String>,
    },
}
An agsiGeometryAreaFromLines object defines an element as the area between top and/or bottom lines. This will typically be used on cross sections or fence diagrams. This is a linking object between model element and the source geometry for the lines. Refer to 6.2.4. Areas from lines for full details of how the area should be interpreted.

JSON schema
{
 "description": "An agsiGeometryAreaFromLines object defines an element as the area between top and/or bottom lines. This will typically be used on cross sections or fence diagrams. This is a linking object between model element and the source geometry for the lines. Refer to 6.2.4. Areas from lines for full details of how the area should be interpreted.",
 "type": "object",
 "anyOf": [
   {
     "required": [
       "agsiGeometryTop"
     ]
   },
   {
     "required": [
       "agsiGeometryBottom"
     ]
   }
 ],
 "properties": {
   "agsiGeometryBottom": {
     "description": "Geometry for bottom line, as embedded agsiGeometryFromFile object. Definition of both top and bottom lines is strongly recommended to minimise the risk of error. Refer to 6.2.4. Areas from lines for further details.",
     "type": "object",
     "$ref": "#/$defs/agsiGeometryFromFile"
   },
   "agsiGeometryTop": {
     "description": "Geometry for top line, as embedded agsiGeometryFromFile object. Definition of both top and bottom lines is strongly recommended to minimise the risk of error. Refer to 6.2.4. Areas from lines for further details.",
     "type": "object",
     "$ref": "#/$defs/agsiGeometryFromFile"
   },
   "description": {
     "description": "Short description of geometry defined here.",
     "type": "string",
     "example": "Section AA, Gotham Clay"
   },
   "geometryID": {
     "description": "Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.",
     "type": "string",
     "example": "SectionAAGCC"
   },
   "remarks": {
     "description": "Additional remarks, if required.",
     "type": "string",
     "example": "Some remarks if required"
   }
 },
 "additionalProperties": false
}

Variants



Variant0

Fields

agsi_geometry_top: AgsiGeometryFromFile

Geometry for top line, as embedded agsiGeometryFromFile object. Definition of both top and bottom lines is strongly recommended to minimise the risk of error. Refer to 6.2.4. Areas from lines for further details.

description: Option<String>

Short description of geometry defined here.

geometry_id: Option<String>

Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.

remarks: Option<String>

Additional remarks, if required.



Variant1

Fields

agsi_geometry_bottom: AgsiGeometryFromFile

Geometry for bottom line, as embedded agsiGeometryFromFile object. Definition of both top and bottom lines is strongly recommended to minimise the risk of error. Refer to 6.2.4. Areas from lines for further details.

description: Option<String>

Short description of geometry defined here.

geometry_id: Option<String>

Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.

remarks: Option<String>

Additional remarks, if required.