AgsiGeometryVolFromSurfacesVariant1AgsiGeometryBottom

Enum AgsiGeometryVolFromSurfacesVariant1AgsiGeometryBottom 

pub enum AgsiGeometryVolFromSurfacesVariant1AgsiGeometryBottom {
    FromFile(AgsiGeometryFromFile),
    Plane(AgsiGeometryPlane),
}
Geometry for bottom surface, as embedded agsiGeometryFromFile or agsiGeometryPlane object. Definition of both top and bottom surfaces is recommended to minimise the risk of error. Refer to 6.2.3. Volumes from surfaces for further details.

JSON schema
{
 "description": "Geometry for bottom surface, as embedded agsiGeometryFromFile or agsiGeometryPlane object. Definition of both top and bottom surfaces is recommended to minimise the risk of error. Refer to 6.2.3. Volumes from surfaces for further details.",
 "type": "object",
 "anyOf": [
   {
     "$ref": "#/$defs/agsiGeometryFromFile"
   },
   {
     "$ref": "#/$defs/agsiGeometryPlane"
   }
 ]
}

Variants