pub enum AgsiObservationExpHoleVariant1 {}Expand description
AgsiObservationExpHoleVariant1
JSON schema
{
"allOf": [
{
"type": "object",
"properties": {
"agsiDataPropertyFromFile": {
"description": "An embedded agsiDataPropertyFromFile object, which may be used to reference an external supporting data file.",
"type": "object",
"$ref": "#/$defs/agsiDataPropertyFromFile"
},
"agsiDataPropertyValue": {
"description": "Array of embedded agsiDataPropertyValue objects. May be used for additional hole metadata or for profiles of test results for this hole, e.g. SPT vs depth/elevation.",
"type": "array",
"items": {
"$ref": "#/$defs/agsiDataPropertyValue"
}
},
"agsiObservationColumn": {
"description": "Array of embedded agsiObservationColumn objects which are typically used to represent geology within the hole, but can also be used for other data. ",
"type": "array",
"items": {
"$ref": "#/$defs/agsiObservationColumn"
}
},
"date": {
"description": "Date of exploration. Recommend using start date for holes that take more than one day.",
"type": "string",
"format": "date",
"example": "2018-05-23"
},
"holeID": {
"description": "Identifier that is unique across the project for exploratory holes. Not necessarily the same as the original hole ID (see holeName). If used, identifiers for holeID should be unique within the AGSi file. ",
"type": "string",
"example": "A/BH01"
},
"holeName": {
"description": "Current name or ID of the exploratory hole for general use.",
"type": "string",
"example": "BH01"
},
"holeType": {
"description": "Type of exploratory hole. Recommend using code from AGS format ABBR code list, e.g. CP+RC, with project specific codes defined using agsProjectCode. Alternatively, short description may be provided, e.g. cable percussion borehole with rotary follow on.",
"type": "string",
"example": "CP+RC"
},
"holeUUID": {
"description": "Universal/global unique identifier (UUID) for the hole. This is optional and is not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity. Other attributes should be used for IDs specific to the producer and/or client (see below).",
"type": "string",
"example": "523ad9ed-4f75-4a55-b251-c566a8b998bd"
},
"profileCoordinates": {
"description": "Coordinates of the line of the exploratory hole (3D, including elevation), i.e. top, bottom and intermediate changes in direction if required. Input as ordered list of coordinate tuples starting at the top. Used for holes that are not vertical, or not straight. May be used for straight vertical holes as alternative to topCoordinate and verticalHoleDepth.",
"type": "array",
"items": {
"$ref": "#/$defs/coordinateTuple"
},
"example": [
[
1275.5,
2195.0,
15.25
],
[
1275.5,
2195.0,
-9.75
]
]
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Original name on logs: BH1"
},
"topCoordinate": {
"description": "Coordinates of the top of the exploratory hole (3D, including elevation) as a coordinate tuple.",
"type": "array",
"$ref": "#/$defs/coordinateTuple",
"example": [
1275.5,
2195.0,
15.25
]
},
"verticalHoleDepth": {
"description": "Final depth of exploratory hole for vertical holes only. For non-vertical or non-straight holes use profileCoordinates instead.",
"type": "number",
"example": 25
}
},
"additionalProperties": false
},
{
"required": [
"holeID",
"profileCoordinates"
]
},
{
"not": {
"required": [
"holeID",
"topCoordinate",
"verticalHoleDepth"
]
}
}
]
}Trait Implementations
Sourceimpl Clone for AgsiObservationExpHoleVariant1
impl Clone for AgsiObservationExpHoleVariant1
Sourcefn clone(&self) -> AgsiObservationExpHoleVariant1
fn clone(&self) -> AgsiObservationExpHoleVariant1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AgsiObservationExpHoleVariant1
impl<'de> Deserialize<'de> for AgsiObservationExpHoleVariant1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&AgsiObservationExpHoleVariant1> for AgsiObservationExpHoleVariant1
impl From<&AgsiObservationExpHoleVariant1> for AgsiObservationExpHoleVariant1
Sourcefn from(value: &AgsiObservationExpHoleVariant1) -> Self
fn from(value: &AgsiObservationExpHoleVariant1) -> Self
Converts to this type from the input type.
Sourceimpl From<AgsiObservationExpHoleVariant1> for AgsiObservationExpHole
impl From<AgsiObservationExpHoleVariant1> for AgsiObservationExpHole
Sourcefn from(value: AgsiObservationExpHoleVariant1) -> Self
fn from(value: AgsiObservationExpHoleVariant1) -> Self
Converts to this type from the input type.
Sourceimpl Ord for AgsiObservationExpHoleVariant1
impl Ord for AgsiObservationExpHoleVariant1
Sourcefn cmp(&self, other: &AgsiObservationExpHoleVariant1) -> Ordering
fn cmp(&self, other: &AgsiObservationExpHoleVariant1) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AgsiObservationExpHoleVariant1
impl PartialEq for AgsiObservationExpHoleVariant1
Sourcefn eq(&self, other: &AgsiObservationExpHoleVariant1) -> bool
fn eq(&self, other: &AgsiObservationExpHoleVariant1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for AgsiObservationExpHoleVariant1
impl PartialOrd for AgsiObservationExpHoleVariant1
impl Copy for AgsiObservationExpHoleVariant1
impl Eq for AgsiObservationExpHoleVariant1
impl StructuralPartialEq for AgsiObservationExpHoleVariant1