AgsFile

Struct AgsFile 

pub struct AgsFile {
Show 15 fields pub approved_by: Option<String>, pub checked_by: Option<String>, pub date: Option<NaiveDate>, pub description: Option<String>, pub file_uri: Option<String>, pub file_uuid: Option<String>, pub made_by: Option<String>, pub produced_by: AgsFileProducedBy, pub project_title: Option<String>, pub reference: Option<String>, pub remarks: Option<String>, pub revision: Option<String>, pub status: Option<String>, pub status_code: Option<String>, pub title: AgsFileTitle,
}
Metadata for the AGSi package (which comprises the AGSi file and included supporting files). The AGSi package should be treated as a document in accordance with standards established for the project. The attributes provided align with good practice BIM, in accordance with ISO19650. It is recommended that, where possible, this object is output at the top of the file, after the schema object, for human readability.

JSON schema
{
 "description": "Metadata for the AGSi package (which comprises the AGSi file and included supporting files).  The AGSi package should be treated as a document in accordance with standards established for the project. The attributes provided align with good practice BIM, in accordance with ISO19650. It is recommended that, where possible, this object is output at the top of the file, after the schema object, for human readability.",
 "type": "object",
 "required": [
   "producedBy",
   "title"
 ],
 "properties": {
   "approvedBy": {
     "description": "Person(s) identified as approver.",
     "type": "string",
     "example": "T Black"
   },
   "checkedBy": {
     "description": "Person(s) identified as checker.",
     "type": "string",
     "example": "P Brown"
   },
   "date": {
     "description": "Date of production.",
     "type": "string",
     "format": "date",
     "example": "2018-10-05"
   },
   "description": {
     "description": "Additional description, if required.",
     "type": "string",
     "example": "Geological model and geotechnical design models produced for Stage 4 design"
   },
   "fileURI": {
     "description": "URI (link address) for the location of this AGSi package within the project document system. Spaces are not permitted in URI strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.",
     "type": "string",
     "format": "uri",
     "example": "https://gothammetro.sharepoint.com/C999/docs/C999-ABC-AX-XX-M3-CG-1234"
   },
   "fileUUID": {
     "description": "Universal unique identifier (UUID) for the AGSi package. This is optional and is not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity. ",
     "type": "string",
     "example": "98e17952-c99d-4d87-8f01-8ba75d29b6ad"
   },
   "madeBy": {
     "description": "Person(s) identified as originator.",
     "type": "string",
     "example": "A Green"
   },
   "producedBy": {
     "description": "Organisation that produced this AGSi package.",
     "type": "string",
     "minLength": 1,
     "example": "ABC Consultants"
   },
   "projectTitle": {
     "description": "Name of project (as used for document management system).",
     "type": "string",
     "example": "Gotham City Metro Purple Line, C999 Geotechnical Package X"
   },
   "reference": {
     "description": "Document reference (typically in accordance with ISO19650, BS1192 or project standards).",
     "type": "string",
     "example": "C999-ABC-AX-XX-M3-CG-1234"
   },
   "remarks": {
     "description": "Additional remarks, if required.",
     "type": "string",
     "example": "Some remarks if required"
   },
   "revision": {
     "description": "Revision reference (typically in accordance with ISO19650 or BS1192 or project standards).",
     "type": "string",
     "example": "P1"
   },
   "status": {
     "description": "Status, typically following recommendations of BS8574.",
     "type": "string",
     "example": "Final"
   },
   "statusCode": {
     "description": "Status code in accordance with ISO19650 (or BS1192 suitability code).",
     "type": "string",
     "example": "S2"
   },
   "title": {
     "description": "Title of the AGSi package (as used for document management system).",
     "type": "string",
     "minLength": 1,
     "example": "Stage 3 Sitewide Ground models"
   }
 },
 "additionalProperties": false
}

Fields

approved_by: Option<String>

Person(s) identified as approver.

checked_by: Option<String>

Person(s) identified as checker.

date: Option<NaiveDate>

Date of production.

description: Option<String>

Additional description, if required.

file_uri: Option<String>

URI (link address) for the location of this AGSi package within the project document system. Spaces are not permitted in URI strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.

file_uuid: Option<String>

Universal unique identifier (UUID) for the AGSi package. This is optional and is not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity.

made_by: Option<String>

Person(s) identified as originator.

produced_by: AgsFileProducedBy

Organisation that produced this AGSi package.

project_title: Option<String>

Name of project (as used for document management system).

reference: Option<String>

Document reference (typically in accordance with ISO19650, BS1192 or project standards).

remarks: Option<String>

Additional remarks, if required.

revision: Option<String>

Revision reference (typically in accordance with ISO19650 or BS1192 or project standards).

status: Option<String>

Status, typically following recommendations of BS8574.

status_code: Option<String>

Status code in accordance with ISO19650 (or BS1192 suitability code).

title: AgsFileTitle

Title of the AGSi package (as used for document management system).

Implementations