AgsProjectDocument

Struct AgsProjectDocument 

pub struct AgsProjectDocument {
Show 14 fields pub author: Option<String>, pub client: Option<String>, pub date: Option<NaiveDate>, pub description: Option<String>, pub document_id: Option<String>, pub document_system_uri: Option<String>, pub document_uri: Option<String>, pub original_reference: Option<String>, pub remarks: Option<String>, pub revision: Option<String>, pub status: Option<String>, pub status_code: Option<String>, pub system_reference: Option<String>, pub title: Option<String>,
}
Metadata for the individual documents or references contained within a document set. Refer to 3.2.3. Documents for further details.

JSON schema
{
 "description": "Metadata for the individual documents or references contained within a document set. Refer to 3.2.3. Documents for further details.",
 "type": "object",
 "properties": {
   "author": {
     "description": "The original author of the document.",
     "type": "string",
     "example": "Boring Drilling Ltd"
   },
   "client": {
     "description": "The original commissioning client for the document.",
     "type": "string",
     "example": "XYZ D&B Contractor"
   },
   "date": {
     "description": "Date of the document (current revision).",
     "type": "string",
     "format": "date",
     "example": "2018-09-06"
   },
   "description": {
     "description": "Further description if required. Typically what the document is commonly known as, given that the formal title may be verbose. Alternatively use for name/title given in project documentation system if this differs from original title.",
     "type": "string",
     "example": "Package A factual report, Volume 1"
   },
   "documentID": {
     "description": "Identifier for the document. May be local to this file or a UUID as required/specified. This is optional and is not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity. If used, identifiers for documentID should be unique at least within each document set (agsProjectDocumentSet object), and preferably unique within the AGSi file. ",
     "type": "string",
     "example": "eac20ae4-25a1-4e68-96f8-cf43b9761b11"
   },
   "documentSystemURI": {
     "description": "URI (link address) for the location of the document within the project document management system. To be used if documentURI attribute used for relative link. Spaces are not permitted in URI strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.",
     "type": "string",
     "format": "uri",
     "example": "https://gothammetro.sharepoint.com/C999/docs/C999-BDL-AX-XX-RP-WG-0002"
   },
   "documentURI": {
     "description": "URI-reference (link address) for the document. This will be a relative link if document included within the AGSi package. For a public domain published reference, the link should be provided here. Spaces are not permitted in URI-reference strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.",
     "type": "string",
     "format": "uri-reference",
     "example": "docs/GI/C999-BDL-AX-XX-RP-WG-0002.pdf"
   },
   "originalReference": {
     "description": "Original reference shown on the document, if different from reference used by project document system (see systemReference).",
     "type": "string",
     "example": "12345/GI/2"
   },
   "remarks": {
     "description": "Additional remarks, if required.",
     "type": "string",
     "example": "Some additional remarks"
   },
   "revision": {
     "description": "Revision reference (typically in accordance with ISO19650 or BS1192).",
     "type": "string",
     "example": "P2"
   },
   "status": {
     "description": "Status as indicated on or within the document, typically following recommendations of BS8574 if applicable.",
     "type": "string",
     "example": "Final"
   },
   "statusCode": {
     "description": "Status code, typically in accordance with ISO19650, or BS1192 suitability code.",
     "type": "string",
     "example": "S2"
   },
   "systemReference": {
     "description": "Document reference used in the project document management system. May differ from original reference shown on document.",
     "type": "string",
     "example": "C999-BDL-AX-XX-RP-WG-0002"
   },
   "title": {
     "description": "Original title on the document.",
     "type": "string",
     "example": "Factual ground investigation report, Gotham City Metro Purple Line, C999 Package A, Volume 1 of 3"
   }
 },
 "additionalProperties": false
}

Fields

author: Option<String>

The original author of the document.

client: Option<String>

The original commissioning client for the document.

date: Option<NaiveDate>

Date of the document (current revision).

description: Option<String>

Further description if required. Typically what the document is commonly known as, given that the formal title may be verbose. Alternatively use for name/title given in project documentation system if this differs from original title.

document_id: Option<String>

Identifier for the document. May be local to this file or a UUID as required/specified. This is optional and is not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity. If used, identifiers for documentID should be unique at least within each document set (agsProjectDocumentSet object), and preferably unique within the AGSi file.

document_system_uri: Option<String>

URI (link address) for the location of the document within the project document management system. To be used if documentURI attribute used for relative link. Spaces are not permitted in URI strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.

document_uri: Option<String>

URI-reference (link address) for the document. This will be a relative link if document included within the AGSi package. For a public domain published reference, the link should be provided here. Spaces are not permitted in URI-reference strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.

original_reference: Option<String>

Original reference shown on the document, if different from reference used by project document system (see systemReference).

remarks: Option<String>

Additional remarks, if required.

revision: Option<String>

Revision reference (typically in accordance with ISO19650 or BS1192).

status: Option<String>

Status as indicated on or within the document, typically following recommendations of BS8574 if applicable.

status_code: Option<String>

Status code, typically in accordance with ISO19650, or BS1192 suitability code.

system_reference: Option<String>

Document reference used in the project document management system. May differ from original reference shown on document.

title: Option<String>

Original title on the document.

Implementations