AgsiGeometryFromFile

Struct AgsiGeometryFromFile 

pub struct AgsiGeometryFromFile {
    pub date: Option<NaiveDate>,
    pub description: Option<String>,
    pub file_format: Option<String>,
    pub file_format_version: Option<String>,
    pub file_part: Option<String>,
    pub file_uri: String,
    pub geometry_id: Option<String>,
    pub geometry_type: Option<String>,
    pub remarks: Option<String>,
    pub revision: Option<String>,
    pub revision_info: Option<String>,
}
An agsiGeometryFromFile object is a pointer to geometry data contained within an external file, such as a CAD or model file. This object also includes metadata describing the file being referenced. Refer to 6.2. Geometry rules and conventions for further requirements and recommendations relating to this object.

JSON schema
{
 "description": "An agsiGeometryFromFile object is a pointer to geometry data contained within an external file, such as a CAD or model file. This object also includes metadata describing the file being referenced. Refer to 6.2. Geometry rules and conventions for further requirements and recommendations relating to this object.",
 "type": "object",
 "required": [
   "fileURI"
 ],
 "properties": {
   "date": {
     "description": "Date of issue of this revision.",
     "type": "string",
     "format": "date",
     "example": "2018-10-07"
   },
   "description": {
     "description": "Short description of geometry defined here.",
     "type": "string",
     "example": "Top of GC"
   },
   "fileFormat": {
     "description": "Format/encoding of the data, i.e. file format. Refer to vocabulary for list of common formats that may be used, or provide concise identification if other format used. Refer to 6.2.1. File formats for geometry for requirements and recommendations relating to file formats.",
     "type": "string",
     "example": "LandXML"
   },
   "fileFormatVersion": {
     "description": "Additional version information for file format used, if required.",
     "type": "string",
     "example": "2.0"
   },
   "filePart": {
     "description": "Pointer to a specific part of a file, where required for disambiguation. For CAD or model files this could be used for the layer/level on which the required data is located. For a geoJSON file with a feature collection this could be used to specify the id of the feature of interest.  Use with caution as the ability to interrogate only a specified layer/level/feature etc. may not be supported in all software.",
     "type": "string",
     "example": "GCTop"
   },
   "fileURI": {
     "description": "URI-reference for the geometry file. This will be a relative link if file is included as part of the AGSi package. Alternatively, a link to a project document system location. Refer to 6.2.1. File formats for geometry for requirements and recommendations relating to linked files. Spaces are not permitted in URI-reference strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.",
     "type": "string",
     "format": "uri-reference",
     "example": "geometry/geology/GCtop.xml"
   },
   "geometryID": {
     "description": "Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.",
     "type": "string",
     "example": "GeologyGCCTop"
   },
   "geometryType": {
     "description": "Nature of geometry represented.",
     "type": "string",
     "example": "Surface"
   },
   "remarks": {
     "description": "Additional remarks, if required.",
     "type": "string",
     "example": "Some remarks if required"
   },
   "revision": {
     "description": "Revision of the referenced file.",
     "type": "string",
     "example": "P2"
   },
   "revisionInfo": {
     "description": "Revision notes for this revision of the referenced file.",
     "type": "string",
     "example": "Updated for GIR rev P2. Additional BH from 2018 GI included."
   }
 },
 "additionalProperties": false
}

Fields

date: Option<NaiveDate>

Date of issue of this revision.

description: Option<String>

Short description of geometry defined here.

file_format: Option<String>

Format/encoding of the data, i.e. file format. Refer to vocabulary for list of common formats that may be used, or provide concise identification if other format used. Refer to 6.2.1. File formats for geometry for requirements and recommendations relating to file formats.

file_format_version: Option<String>

Additional version information for file format used, if required.

file_part: Option<String>

Pointer to a specific part of a file, where required for disambiguation. For CAD or model files this could be used for the layer/level on which the required data is located. For a geoJSON file with a feature collection this could be used to specify the id of the feature of interest. Use with caution as the ability to interrogate only a specified layer/level/feature etc. may not be supported in all software.

file_uri: String

URI-reference for the geometry file. This will be a relative link if file is included as part of the AGSi package. Alternatively, a link to a project document system location. Refer to 6.2.1. File formats for geometry for requirements and recommendations relating to linked files. Spaces are not permitted in URI-reference strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.

geometry_id: Option<String>

Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.

geometry_type: Option<String>

Nature of geometry represented.

remarks: Option<String>

Additional remarks, if required.

revision: Option<String>

Revision of the referenced file.

revision_info: Option<String>

Revision notes for this revision of the referenced file.

Implementations