pub struct AgsiObservationPoint {
pub agsi_data_property_from_file: Option<AgsiDataPropertyFromFile>,
pub agsi_data_property_value: Vec<AgsiDataPropertyValue>,
pub coordinate: CoordinateTuple,
pub date: Option<NaiveDate>,
pub made_by: Option<String>,
pub observation_id: Option<String>,
pub observation_nature: Option<String>,
pub observation_text: Option<String>,
pub remarks: Option<String>,
}Expand description
An agsiObservationPoint is an observation related to a single geographic point, which may be defined in 2D or 3D space as required. Observations can be text or numeric value(s). Alternatively, a single agsiObservationPoint object can be used to provide attributed data using embedded agsiDataPropertyValue objects. For observations that relate to a line, area, volume or series of points, use agsiObservationShape. For GI exploratory holes and their data, use agsiObservationExpHole.
JSON schema
{
"description": "An agsiObservationPoint is an observation related to a single geographic point, which may be defined in 2D or 3D space as required. Observations can be text or numeric value(s). Alternatively, a single agsiObservationPoint object can be used to provide attributed data using embedded agsiDataPropertyValue objects. For observations that relate to a line, area, volume or series of points, use agsiObservationShape. For GI exploratory holes and their data, use agsiObservationExpHole.",
"type": "object",
"required": [
"coordinate"
],
"properties": {
"agsiDataPropertyFromFile": {
"description": "An embedded agsiDataPropertyFromFile object, which may be used to reference to an external supporting data file.",
"type": "object",
"$ref": "#/$defs/agsiDataPropertyFromFile"
},
"agsiDataPropertyValue": {
"description": "Array of embedded agsiDataPropertyValue objects. May be used to provide attributed data for this observation (numeric and/or text).",
"type": "array",
"items": {
"$ref": "#/$defs/agsiDataPropertyValue"
}
},
"coordinate": {
"description": "Coordinates of the location of the observation point, as a coordinate tuple. Coordinates provided may be 2D (x,y) or 3D (x,y,z).",
"type": "array",
"$ref": "#/$defs/coordinateTuple",
"example": [
1280.0,
2195.0
]
},
"date": {
"description": "Date of observation, if applicable.",
"type": "string",
"format": "date",
"example": "2018-05-18"
},
"madeBy": {
"description": "Name and/or organisation of person(s) making the observation, if applicable.",
"type": "string",
"example": "J Smith (ABC Consultants)"
},
"observationID": {
"description": "Identifier for this observation. May be local to this file or a UUID as required/specified. This is optional and not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity, and some software/applications may require it. If used, identifiers for observationID should be unique at least within each observation set (agsiObservationSet object), and preferably unique within the AGSi file. ",
"type": "string",
"example": "GIHole/A/Obs/001"
},
"observationNature": {
"description": "Description of the nature of the observation (use observationText for the observation itself).",
"type": "string",
"example": "GI field notes"
},
"observationText": {
"description": "Description of the observation as text. Not required if agsiDataPropertyValue used to provide attributed data.",
"type": "string",
"example": "Original proposed location of BH01. Hole moved due to concrete obstruction encountered at this location. "
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some remarks if required"
}
},
"additionalProperties": false
}Fields
agsi_data_property_from_file: Option<AgsiDataPropertyFromFile>An embedded agsiDataPropertyFromFile object, which may be used to reference to an external supporting data file.
agsi_data_property_value: Vec<AgsiDataPropertyValue>Array of embedded agsiDataPropertyValue objects. May be used to provide attributed data for this observation (numeric and/or text).
coordinate: CoordinateTupleCoordinates of the location of the observation point, as a coordinate tuple. Coordinates provided may be 2D (x,y) or 3D (x,y,z).
date: Option<NaiveDate>Date of observation, if applicable.
made_by: Option<String>Name and/or organisation of person(s) making the observation, if applicable.
observation_id: Option<String>Identifier for this observation. May be local to this file or a UUID as required/specified. This is optional and not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity, and some software/applications may require it. If used, identifiers for observationID should be unique at least within each observation set (agsiObservationSet object), and preferably unique within the AGSi file.
observation_nature: Option<String>Description of the nature of the observation (use observationText for the observation itself).
observation_text: Option<String>Description of the observation as text. Not required if agsiDataPropertyValue used to provide attributed data.
remarks: Option<String>Additional remarks, if required.
Implementations
Sourceimpl AgsiObservationPoint
impl AgsiObservationPoint
pub fn builder() -> AgsiObservationPoint