pub enum AgsiGeometryLayer {
Variant0 {
description: Option<String>,
geometry_id: Option<String>,
remarks: Option<String>,
top_elevation: f64,
},
Variant1 {
bottom_elevation: f64,
description: Option<String>,
geometry_id: Option<String>,
remarks: Option<String>,
},
}Expand description
An agsiGeometryLayer object is a volumetric element bounded by two infinite horizontal planes at specified elevations. May be used for defining each element in a stratigraphical column (one dimensional) model. See 6.2.5. Simple 1D layers for interpretation.
JSON schema
{
"description": "An agsiGeometryLayer object is a volumetric element bounded by two infinite horizontal planes at specified elevations. May be used for defining each element in a stratigraphical column (one dimensional) model. See 6.2.5. Simple 1D layers for interpretation.",
"type": "object",
"anyOf": [
{
"required": [
"topElevation"
]
},
{
"required": [
"bottomElevation"
]
}
],
"properties": {
"bottomElevation": {
"description": "Elevation (z) of the bottom surface. Definition of both top and bottom surfaces is recommended to minimise the risk of error.",
"type": "number",
"example": -30
},
"description": {
"description": "Short description of geometry defined here.",
"type": "string",
"example": "Design profile, pile design: Gotham Clay"
},
"geometryID": {
"description": "Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.",
"type": "string",
"example": "DesignPileGCC"
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some remarks if required"
},
"topElevation": {
"description": "Elevation (z) of the top surface. Definition of both top and bottom surfaces is recommended to minimise the risk of error.",
"type": "number",
"example": 6
}
},
"additionalProperties": false
}Variants
Variant0
Fields
geometry_id: Option<String>Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.
Variant1
Fields
geometry_id: Option<String>Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.