pub enum AgsiGeometryVolFromSurfaces {
Variant0 {
agsi_geometry_top: AgsiGeometryVolFromSurfacesVariant0AgsiGeometryTop,
description: Option<String>,
geometry_id: Option<String>,
remarks: Option<String>,
},
Variant1 {
agsi_geometry_bottom: AgsiGeometryVolFromSurfacesVariant1AgsiGeometryBottom,
description: Option<String>,
geometry_id: Option<String>,
remarks: Option<String>,
},
}Expand description
An agsiGeometryVolFromSurfaces object defines an element as the volumetric element (solid) between top and/or bottom surfaces. This is a linking object between model element and the source geometry for the surfaces, which will normally be agsiGeometryFromFile objects. Refer to 6.2.3. Volumes from surfaces for full details of how the volume should be interpreted.
JSON schema
{
"description": "An agsiGeometryVolFromSurfaces object defines an element as the volumetric element (solid) between top and/or bottom surfaces. This is a linking object between model element and the source geometry for the surfaces, which will normally be agsiGeometryFromFile objects. Refer to 6.2.3. Volumes from surfaces for full details of how the volume should be interpreted.",
"type": "object",
"anyOf": [
{
"required": [
"agsiGeometryTop"
]
},
{
"required": [
"agsiGeometryBottom"
]
}
],
"properties": {
"agsiGeometryBottom": {
"description": "Geometry for bottom surface, as embedded agsiGeometryFromFile or agsiGeometryPlane object. Definition of both top and bottom surfaces is recommended to minimise the risk of error. Refer to 6.2.3. Volumes from surfaces for further details.",
"type": "object",
"anyOf": [
{
"$ref": "#/$defs/agsiGeometryFromFile"
},
{
"$ref": "#/$defs/agsiGeometryPlane"
}
]
},
"agsiGeometryTop": {
"description": "Geometry for top surface, as embedded agsiGeometryFromFile or agsiGeometryPlane object. Definition of both top and bottom surfaces is recommended to minimise the risk of error. Refer to 6.2.3. Volumes from surfaces for further details.",
"type": "object",
"anyOf": [
{
"$ref": "#/$defs/agsiGeometryFromFile"
},
{
"$ref": "#/$defs/agsiGeometryPlane"
}
]
},
"description": {
"description": "Short description of geometry defined here.",
"type": "string",
"example": "Gotham Clay"
},
"geometryID": {
"description": "Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.",
"type": "string",
"example": "GeologyGCC"
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some remarks if required"
}
},
"additionalProperties": false
}Variants
Variant0
Fields
agsi_geometry_top: AgsiGeometryVolFromSurfacesVariant0AgsiGeometryTopGeometry for top surface, as embedded agsiGeometryFromFile or agsiGeometryPlane object. Definition of both top and bottom surfaces is recommended to minimise the risk of error. Refer to 6.2.3. Volumes from surfaces for further details.
geometry_id: Option<String>Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.
Variant1
Fields
agsi_geometry_bottom: AgsiGeometryVolFromSurfacesVariant1AgsiGeometryBottomGeometry for bottom surface, as embedded agsiGeometryFromFile or agsiGeometryPlane object. Definition of both top and bottom surfaces is recommended to minimise the risk of error. Refer to 6.2.3. Volumes from surfaces for further details.
geometry_id: Option<String>Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.