pub struct AgsProjectCode {
pub code_id: AgsProjectCodeCodeId,
pub description: AgsProjectCodeDescription,
pub is_standard: Option<bool>,
pub remarks: Option<String>,
pub units: Option<String>,
}Expand description
Codes referenced by other parts of the schema such as the Data group objects (property and parameter codes) and Observation group objects (hole types, legend codes and geology codes). The codes may be project specific or from a standard list, e.g. AGSi standard code list or ABBR codes inherited from AGS factual data. Inclusion of standard AGSi code list or AGS ABBR codes used is optional (unless required by specification) provided that the code list used is identifed using agsProjectCodeSet. Refer to 3.2.4. Codes for Data objects and 3.2.5. Codes where use of AGS ABBR recommended for further details.
JSON schema
{
"description": "Codes referenced by other parts of the schema such as the Data group objects (property and parameter codes) and Observation group objects (hole types, legend codes and geology codes). The codes may be project specific or from a standard list, e.g. AGSi standard code list or ABBR codes inherited from AGS factual data. Inclusion of standard AGSi code list or AGS ABBR codes used is optional (unless required by specification) provided that the code list used is identifed using agsProjectCodeSet. Refer to 3.2.4. Codes for Data objects and 3.2.5. Codes where use of AGS ABBR recommended for further details.",
"type": "object",
"required": [
"codeID",
"description"
],
"properties": {
"codeID": {
"description": "Codes, including project specific codes, used in this AGSi file. All codes within each code set shall be unique. ",
"type": "string",
"minLength": 1,
"example": "UndrainedShearStrength"
},
"description": {
"description": "Short description of what the code represents.",
"type": "string",
"minLength": 1,
"example": "Undrained shear strength"
},
"isStandard": {
"description": "true if code is from standard dictionary such as the AGSi code list. If omitted, should be assumed to be false, i.e. project specific or other non-standard code.",
"type": "boolean",
"example": true
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some additional remarks"
},
"units": {
"description": "Units of measurement if code represents a property or parameter. ",
"type": "string",
"example": "kPa"
}
},
"additionalProperties": false
}Fields
code_id: AgsProjectCodeCodeIdCodes, including project specific codes, used in this AGSi file. All codes within each code set shall be unique.
description: AgsProjectCodeDescriptionShort description of what the code represents.
is_standard: Option<bool>true if code is from standard dictionary such as the AGSi code list. If omitted, should be assumed to be false, i.e. project specific or other non-standard code.
remarks: Option<String>Additional remarks, if required.
units: Option<String>Units of measurement if code represents a property or parameter.
Implementations
Sourceimpl AgsProjectCode
impl AgsProjectCode
pub fn builder() -> AgsProjectCode