pub struct AgsProjectCodeSet {
pub ags_project_code: Vec<AgsProjectCode>,
pub code_set_id: Option<String>,
pub concatenation_allow: Option<bool>,
pub concatenation_character: Option<String>,
pub description: Option<String>,
pub remarks: Option<String>,
pub source_description: Option<String>,
pub source_uri: Option<String>,
pub used_by_attribute: AgsProjectCodeSetUsedByAttribute,
pub used_by_object: AgsProjectCodeSetUsedByObject,
}Expand description
Sets of codes referenced by other parts of the schema such as the Data group objects (property and parameter codes) and Observation group objects (hole types, legend codes and geology codes). The codes may be project specific or from a standard list, e.g. AGSi standard code list or ABBR codes inherited from AGS factual data. An agsProjectCodeSet object is required for each object attribute using a set of codes. The codes for each code set are defined using embedded agsProjectCode objects or found at the external source specified in this object. Refer to 3.2.4. Codes for Data objects and 3.2.5. Codes where use of AGS ABBR recommended for further details.
JSON schema
{
"description": "Sets of codes referenced by other parts of the schema such as the Data group objects (property and parameter codes) and Observation group objects (hole types, legend codes and geology codes). The codes may be project specific or from a standard list, e.g. AGSi standard code list or ABBR codes inherited from AGS factual data. An agsProjectCodeSet object is required for each object attribute using a set of codes. The codes for each code set are defined using embedded agsProjectCode objects or found at the external source specified in this object. Refer to 3.2.4. Codes for Data objects and 3.2.5. Codes where use of AGS ABBR recommended for further details.",
"type": "object",
"required": [
"usedByAttribute",
"usedByObject"
],
"properties": {
"agsProjectCode": {
"description": "Array of embedded agsProjectCode object(s).",
"type": "array",
"items": {
"$ref": "#/$defs/agsProjectCode"
}
},
"codeSetID": {
"description": "Identifier for this code set. May be local to this file or a UUID as required/specified. This is optional and is not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity. If used, identifiers for codeSetID should be unique within the AGSi file. ",
"type": "string",
"example": "CodeSetParameter"
},
"concatenationAllow": {
"description": "true if concatenation of any combination of codes in the list is permitted, e.g. composite exploratory hole types when using AGS ABBR codes. Assume false (not permitted) if attribute omitted.",
"type": "boolean",
"example": false
},
"concatenationCharacter": {
"description": "Linking character(s) used for concatenation, if permitted. Input blank string if none. ",
"type": "string",
"example": "+"
},
"description": {
"description": "Name or short description of the code set.",
"type": "string",
"example": "Parameter codes"
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some additional remarks"
},
"sourceDescription": {
"description": "Description of the source of the list of codes to be used for this set, if applicable. This could be a published source, a project reference or a file provided within the AGSi package. For properties or parameters, use of the AGSi code list is recommended, but it can be changed to an alternate list, e.g. lists published by other agencies (UK or overseas) or major projects/clientsOptional if the codes are provided as agsProjectCode objects.",
"type": "string",
"example": "AGSi standard code list"
},
"sourceURI": {
"description": "URI-reference link to source of list of codes to be used for this set, if applicable. This could be a published source, link to a project reference, or a file provided within the AGSi package. For properties or parameters, use of the AGSi code list is recommended, but it can be changed to an alternate list, e.g. lists published by other agencies (UK or overseas) or major projects/clients. Optional if the codes are provided as agsProjectCode objects. Spaces are not permitted in URI-reference strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.",
"type": "string",
"format": "uri-reference",
"example": "https://ags-data-format-wg.gitlab.io/agsi/agsi_standard/1.0.1/Codes_Codelist/"
},
"usedByAttribute": {
"description": "Name of the attribute of the AGSi object that references this code set.",
"type": "string",
"minLength": 1,
"example": "codeID"
},
"usedByObject": {
"description": "Name of the AGSi object that references this code set.",
"type": "string",
"minLength": 1,
"example": "agsiDataParameterValue"
}
},
"additionalProperties": false
}Fields
ags_project_code: Vec<AgsProjectCode>Array of embedded agsProjectCode object(s).
code_set_id: Option<String>Identifier for this code set. May be local to this file or a UUID as required/specified. This is optional and is not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity. If used, identifiers for codeSetID should be unique within the AGSi file.
concatenation_allow: Option<bool>true if concatenation of any combination of codes in the list is permitted, e.g. composite exploratory hole types when using AGS ABBR codes. Assume false (not permitted) if attribute omitted.
concatenation_character: Option<String>Linking character(s) used for concatenation, if permitted. Input blank string if none.
description: Option<String>Name or short description of the code set.
remarks: Option<String>Additional remarks, if required.
source_description: Option<String>Description of the source of the list of codes to be used for this set, if applicable. This could be a published source, a project reference or a file provided within the AGSi package. For properties or parameters, use of the AGSi code list is recommended, but it can be changed to an alternate list, e.g. lists published by other agencies (UK or overseas) or major projects/clientsOptional if the codes are provided as agsProjectCode objects.
source_uri: Option<String>URI-reference link to source of list of codes to be used for this set, if applicable. This could be a published source, link to a project reference, or a file provided within the AGSi package. For properties or parameters, use of the AGSi code list is recommended, but it can be changed to an alternate list, e.g. lists published by other agencies (UK or overseas) or major projects/clients. Optional if the codes are provided as agsProjectCode objects. Spaces are not permitted in URI-reference strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.
used_by_attribute: AgsProjectCodeSetUsedByAttributeName of the attribute of the AGSi object that references this code set.
used_by_object: AgsProjectCodeSetUsedByObjectName of the AGSi object that references this code set.
Implementations
Sourceimpl AgsProjectCodeSet
impl AgsProjectCodeSet
pub fn builder() -> AgsProjectCodeSet