pub struct AgsProjectDocumentSet {
pub ags_project_document: Vec<AgsProjectDocument>,
pub description: Option<String>,
pub document_set_id: AgsProjectDocumentSetDocumentSetId,
pub remarks: Option<String>,
}Expand description
Container and metadata for a set of supporting documents or reference information, which may be referenced from other parts of the schema. This container must be used and referenced, even if there is only one document within it. Refer to 3.2.3. Documents for further details.
JSON schema
{
"description": "Container and metadata for a set of supporting documents or reference information, which may be referenced from other parts of the schema. This container must be used and referenced, even if there is only one document within it. Refer to 3.2.3. Documents for further details.",
"type": "object",
"required": [
"documentSetID"
],
"properties": {
"agsProjectDocument": {
"description": "Array of embedded agsProjectDocument object(s).",
"type": "array",
"items": {
"$ref": "#/$defs/agsProjectDocument"
}
},
"description": {
"description": "Brief description, i.e. what this set of documents is commonly known as.",
"type": "string",
"example": "Package A factual report"
},
"documentSetID": {
"description": "Identifier for this document set. May be local to this file or a UUID as required/specified. Identifiers for documentSetID shall be unique within an AGSi file. Referenced by other parts of the schema.",
"type": "string",
"minLength": 1,
"example": "ExampleDocSetID"
},
"remarks": {
"description": "Additional remarks, if required",
"type": "string",
"example": "Some additional remarks"
}
},
"additionalProperties": false
}Fields
ags_project_document: Vec<AgsProjectDocument>Array of embedded agsProjectDocument object(s).
description: Option<String>Brief description, i.e. what this set of documents is commonly known as.
document_set_id: AgsProjectDocumentSetDocumentSetIdIdentifier for this document set. May be local to this file or a UUID as required/specified. Identifiers for documentSetID shall be unique within an AGSi file. Referenced by other parts of the schema.
remarks: Option<String>Additional remarks, if required
Implementations
Sourceimpl AgsProjectDocumentSet
impl AgsProjectDocumentSet
pub fn builder() -> AgsProjectDocumentSet