pub struct AgsProjectInvestigation {Show 21 fields
pub agsi_data_property_from_file: Vec<AgsiDataPropertyFromFile>,
pub agsi_data_property_value: Vec<AgsiDataPropertyValue>,
pub client: Option<String>,
pub contractor: Option<String>,
pub data_document_set_id: Option<String>,
pub description: Option<String>,
pub engineer: Option<String>,
pub fieldwork_date_start: Option<NaiveDate>,
pub investigation_id: AgsProjectInvestigationInvestigationId,
pub investigation_name: AgsProjectInvestigationInvestigationName,
pub location_coordinate_global: Option<CoordinateTuple>,
pub location_coordinate_project: Option<CoordinateTuple>,
pub location_description: Option<String>,
pub parent_project_name: Option<String>,
pub remarks: Option<String>,
pub report_document_set_id: Option<String>,
pub scope_description: Option<String>,
pub specification_document_set_id: Option<String>,
pub subcontractors: Option<String>,
pub ultimate_project_client: Option<String>,
pub ultimate_project_name: Option<String>,
}Expand description
Basic metadata for investigations, generally ground investigations. Referenced from various parts of the schema. More detailed metadata may be provided using embedded agsiDataPropertyValue or agsiDataPropertyFromFile objects. Refer to 3.2.1. Projects and investigations for further details.
JSON schema
{
"description": "Basic metadata for investigations, generally ground investigations. Referenced from various parts of the schema. More detailed metadata may be provided using embedded agsiDataPropertyValue or agsiDataPropertyFromFile objects. Refer to 3.2.1. Projects and investigations for further details.",
"type": "object",
"required": [
"investigationID",
"investigationName"
],
"properties": {
"agsiDataPropertyFromFile": {
"description": "An embedded agsiDataPropertyFromFile object, which may be used to reference to an external supporting data file.",
"type": "array",
"items": {
"$ref": "#/$defs/agsiDataPropertyFromFile"
}
},
"agsiDataPropertyValue": {
"description": "Array of embedded agsiDataPropertyValue objects. Used to provide further metadata relating to the investigation, if required.",
"type": "array",
"items": {
"$ref": "#/$defs/agsiDataPropertyValue"
}
},
"client": {
"description": "Commissioning (contracting) client for the investigation.",
"type": "string",
"example": "XYZ D&B Contractor"
},
"contractor": {
"description": "Contractor undertaking the investigation.",
"type": "string",
"example": "Boring Drilling Ltd"
},
"dataDocumentSetID": {
"description": "Reference to the data for the GI, typically the AGS (factual) data, details of which should be provided in an agsProjectDocumentSet object.",
"type": "string",
"example": "ExampleDocSetID"
},
"description": {
"description": "Further description of investigation, if required.",
"type": "string",
"example": "Preliminary sitewide investigation, March-July 2018"
},
"engineer": {
"description": "Organisation acting as Engineer, Investigation Supervisor, Contract Administrator or equivalent. If technical and contractual roles are split, then include both.",
"type": "string",
"example": "ABC Consultants"
},
"fieldworkDateStart": {
"description": "Date of start of fieldwork. Date in ISO 8601 format so it could be to nearest month (2019-05) or just the year if exact date not available.",
"type": "string",
"format": "date",
"example": "2018-08-21"
},
"investigationID": {
"description": "Identifier for this investigation. May be local to this file or a UUID as required/specified. Identifiers for investigationID shall be unique within an AGSi file. Referenced by other parts of the schema such as agsiObservationSet.",
"type": "string",
"minLength": 1,
"example": "GIPackageA"
},
"investigationName": {
"description": "Name of investigation.",
"type": "string",
"minLength": 1,
"example": "Gotham City Metro Purple Line, C999 Package A"
},
"locationCoordinateGlobal": {
"description": "Coordinates, in global coordinate system (national or regional system, as defined in agsProjectCoordinateSystem) of a point that represents the general location of the investigation, typically the middle of the site.",
"type": "array",
"$ref": "#/$defs/coordinateTuple",
"example": [
475270.0,
137965.0
]
},
"locationCoordinateProject": {
"description": "Coordinates, in a relevant model coordinate system (if applicable), of a point that represents the general location of the investigation, typically the middle of the site. Relevant system will be usually be a 3D system that is used for all 3D models, or a 2D map system. Do not use this attribute if multiple different 3D model systems are in use.",
"type": "array",
"$ref": "#/$defs/coordinateTuple",
"example": [
25500.0,
13200.0
]
},
"locationDescription": {
"description": "Brief description that locates the site. Could be a postal address.",
"type": "string",
"example": "Gotham City, west, central and southeast"
},
"parentProjectName": {
"description": "Name of the parent project that this investigation is for. If parent is ultimate parent project, then may be left blank.",
"type": "string",
"example": "C999 Area A Phase 1 Design and Build"
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some additional remarks"
},
"reportDocumentSetID": {
"description": "Reference to the reports relating to the investigation, details of which should be provided in an agsProjectDocumentSet object.",
"type": "string",
"example": "ExampleDocSetID"
},
"scopeDescription": {
"description": "Brief description of scope.",
"type": "string",
"example": "Preliminary investigation comprising 27 boreholes of which 15 extended by rotary coring up to 55m depth, 45 CPT (max 15m), 35 trial pits, 26 dynamic sampling holes, geotechnical and contamination sampling and testing, piezometric monitoring, limited gas monitoring."
},
"specificationDocumentSetID": {
"description": "Reference to the specification for the GI, details of which should be provided in an agsProjectDocumentSet object.",
"type": "string",
"example": "ExampleDocSetID"
},
"subcontractors": {
"description": "List of significant subcontractors or suppliers working on the investigation. List as a text string, not an array.",
"type": "string",
"example": "Acme Specialist Lab, XYZ Environmental Lab"
},
"ultimateProjectClient": {
"description": "Client for the ultimate parent project.",
"type": "string",
"example": "City Transport Authority"
},
"ultimateProjectName": {
"description": "Name of the ultimate parent project that this investigation is for.",
"type": "string",
"example": "Gotham City Metro Purple Line"
}
},
"additionalProperties": false
}Fields
agsi_data_property_from_file: Vec<AgsiDataPropertyFromFile>An embedded agsiDataPropertyFromFile object, which may be used to reference to an external supporting data file.
agsi_data_property_value: Vec<AgsiDataPropertyValue>Array of embedded agsiDataPropertyValue objects. Used to provide further metadata relating to the investigation, if required.
client: Option<String>Commissioning (contracting) client for the investigation.
contractor: Option<String>Contractor undertaking the investigation.
data_document_set_id: Option<String>Reference to the data for the GI, typically the AGS (factual) data, details of which should be provided in an agsProjectDocumentSet object.
description: Option<String>Further description of investigation, if required.
engineer: Option<String>Organisation acting as Engineer, Investigation Supervisor, Contract Administrator or equivalent. If technical and contractual roles are split, then include both.
fieldwork_date_start: Option<NaiveDate>Date of start of fieldwork. Date in ISO 8601 format so it could be to nearest month (2019-05) or just the year if exact date not available.
investigation_id: AgsProjectInvestigationInvestigationIdIdentifier for this investigation. May be local to this file or a UUID as required/specified. Identifiers for investigationID shall be unique within an AGSi file. Referenced by other parts of the schema such as agsiObservationSet.
investigation_name: AgsProjectInvestigationInvestigationNameName of investigation.
location_coordinate_global: Option<CoordinateTuple>Coordinates, in global coordinate system (national or regional system, as defined in agsProjectCoordinateSystem) of a point that represents the general location of the investigation, typically the middle of the site.
location_coordinate_project: Option<CoordinateTuple>Coordinates, in a relevant model coordinate system (if applicable), of a point that represents the general location of the investigation, typically the middle of the site. Relevant system will be usually be a 3D system that is used for all 3D models, or a 2D map system. Do not use this attribute if multiple different 3D model systems are in use.
location_description: Option<String>Brief description that locates the site. Could be a postal address.
parent_project_name: Option<String>Name of the parent project that this investigation is for. If parent is ultimate parent project, then may be left blank.
remarks: Option<String>Additional remarks, if required.
report_document_set_id: Option<String>Reference to the reports relating to the investigation, details of which should be provided in an agsProjectDocumentSet object.
scope_description: Option<String>Brief description of scope.
specification_document_set_id: Option<String>Reference to the specification for the GI, details of which should be provided in an agsProjectDocumentSet object.
subcontractors: Option<String>List of significant subcontractors or suppliers working on the investigation. List as a text string, not an array.
ultimate_project_client: Option<String>Client for the ultimate parent project.
ultimate_project_name: Option<String>Name of the ultimate parent project that this investigation is for.
Implementations
Sourceimpl AgsProjectInvestigation
impl AgsProjectInvestigation
pub fn builder() -> AgsProjectInvestigation