pub struct AgsSchema {
pub link: Option<String>,
pub name: AgsSchemaName,
pub version: AgsSchemaVersion,
}Expand description
Defines the schema used for the AGSi file. It is recommended that, where possible, this object is output at the top of the file, for human readability.
JSON schema
{
"description": "Defines the schema used for the AGSi file. It is recommended that, where possible, this object is output at the top of the file, for human readability.",
"type": "object",
"required": [
"name",
"version"
],
"properties": {
"link": {
"description": "Web link (uri) to the AGS schema used herein.",
"type": "string",
"format": "uri",
"example": "https://ags-data-format-wg.gitlab.io/agsi/agsi_standard/1.0.1/"
},
"name": {
"description": "Name of the AGS schema used herein.",
"type": "string",
"minLength": 1,
"example": "AGSi"
},
"version": {
"description": "Version of the named AGS schema used herein.",
"type": "string",
"minLength": 1,
"example": "1.0.1"
}
},
"additionalProperties": false
}Fields
link: Option<String>Web link (uri) to the AGS schema used herein.
name: AgsSchemaNameName of the AGS schema used herein.
version: AgsSchemaVersionVersion of the named AGS schema used herein.
Implementations