pub struct AgsiDataParameterValue {
pub case_id: Option<String>,
pub code_id: AgsiDataParameterValueCodeId,
pub data_id: Option<String>,
pub remarks: Option<String>,
pub value_numeric: Option<f64>,
pub value_profile: Option<ValueProfile>,
pub value_profile_ind_var_code_id: Option<String>,
pub value_text: Option<String>,
}Expand description
Each agsiDataParameterValue object provides the data for a single defined parameter. The parameter value conveyed may be numeric, a profile of numeric values (e.g. a design line) or text. Refer to 7.2. Data rules and conventions for further details.
JSON schema
{
"description": "Each agsiDataParameterValue object provides the data for a single defined parameter. The parameter value conveyed may be numeric, a profile of numeric values (e.g. a design line) or text. Refer to 7.2. Data rules and conventions for further details.",
"type": "object",
"required": [
"codeID"
],
"properties": {
"caseID": {
"description": "Code (or text) that identifies the use case for a parameter. See 7.2.4. Use of (data) case for example use cases. If the input is a code, this shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. May be left blank or omitted, but the combination of codeID and caseID shall be unique for the instances of this object contained within a single parent object instance.",
"type": "string",
"example": "EC7Pile"
},
"codeID": {
"description": "Code that identifies the parameter. Codes should be defined in either an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. The codes used by the instances of this object contained within a single parent object instance shall be unique, except that if caseID is used then only the combination of codeID and caseID needs to be unique.",
"type": "string",
"minLength": 1,
"example": "UndrainedShearStrength"
},
"dataID": {
"description": "Identifier for this data object. May be local to this file but all identifiers used within the Data group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.",
"type": "string",
"example": "42f18976-7352-4f67-9a6e-df89788343a7"
},
"remarks": {
"description": "Additional remarks, if required",
"type": "string",
"example": "Some remarks if required"
},
"valueNumeric": {
"description": "Numeric value of parameter, if applicable.",
"type": "number",
"example": 75
},
"valueProfile": {
"description": "The profile of values as an ordered list of tuples of [independent variable value, parameter value]. Typically used to represent design lines. Refer to 1.6.9. Profiles or arrays of coordinate tuples for further information.",
"type": "array",
"$ref": "#/$defs/valueProfile",
"example": [
[
6.0,
100.0
],
[
-24.0,
280.0
]
]
},
"valueProfileIndVarCodeID": {
"description": "Code that identifies the independent variable for a profile, i.e. what the property value varies against. The code shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object.",
"type": "string",
"example": "Elevation"
},
"valueText": {
"description": "Text based value of parameter, if applicable. For a profile (see below), this could be used for a concise description or representation of the profile. Unless specified otherwise, this attribute should only be used when the value is not numeric, i.e. valueNumeric not used.",
"type": "string",
"example": "100 + 6z (z=0 @ +6.0mOD)"
}
},
"additionalProperties": false
}Fields
case_id: Option<String>Code (or text) that identifies the use case for a parameter. See 7.2.4. Use of (data) case for example use cases. If the input is a code, this shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. May be left blank or omitted, but the combination of codeID and caseID shall be unique for the instances of this object contained within a single parent object instance.
code_id: AgsiDataParameterValueCodeIdCode that identifies the parameter. Codes should be defined in either an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. The codes used by the instances of this object contained within a single parent object instance shall be unique, except that if caseID is used then only the combination of codeID and caseID needs to be unique.
data_id: Option<String>Identifier for this data object. May be local to this file but all identifiers used within the Data group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.
remarks: Option<String>Additional remarks, if required
value_numeric: Option<f64>value_profile: Option<ValueProfile>The profile of values as an ordered list of tuples of [independent variable value, parameter value]. Typically used to represent design lines. Refer to 1.6.9. Profiles or arrays of coordinate tuples for further information.
value_profile_ind_var_code_id: Option<String>Code that identifies the independent variable for a profile, i.e. what the property value varies against. The code shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object.
value_text: Option<String>Text based value of parameter, if applicable. For a profile (see below), this could be used for a concise description or representation of the profile. Unless specified otherwise, this attribute should only be used when the value is not numeric, i.e. valueNumeric not used.
Implementations
Sourceimpl AgsiDataParameterValue
impl AgsiDataParameterValue
pub fn builder() -> AgsiDataParameterValue