pub struct AgsiDataPropertyFromFile {
pub data_id: Option<String>,
pub date: Option<String>,
pub description: Option<String>,
pub file_format: Option<String>,
pub file_format_version: Option<String>,
pub file_part: Option<String>,
pub file_uri: String,
pub remarks: Option<String>,
pub revision: Option<String>,
pub revision_info: Option<String>,
}Expand description
An agsiDataPropertyFromFile object is a pointer to data contained within an external file, such as an AGS, CSV or spreadsheet file. This object also includes metadata describing the file being referenced. Refer to 7.2.5. Limitations of agsiDataPropertyFromFile for further requirements and recommendations relating to this object.
JSON schema
{
"description": "An agsiDataPropertyFromFile object is a pointer to data contained within an external file, such as an AGS, CSV or spreadsheet file. This object also includes metadata describing the file being referenced. Refer to 7.2.5. Limitations of agsiDataPropertyFromFile for further requirements and recommendations relating to this object.",
"type": "object",
"required": [
"fileURI"
],
"properties": {
"dataID": {
"description": "Identifier for this data object. May be local to this file but all identifiers used within the Data group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.",
"type": "string",
"example": "42f18976-7352-4f67-9a6e-df89788343a7"
},
"date": {
"description": "Date of issue of this revision.",
"type": "string",
"example": "2018-10-01"
},
"description": {
"description": "Short description of data file defined here.",
"type": "string",
"example": "Additional data points for top of Gotham Clay from legacy boreholes, based on points marked on plan reference xxxx in report yyyy etc"
},
"fileFormat": {
"description": "Format/encoding of the data, i.e. file format. Refer to 9.2. Vocabulary for list of common formats that may be used, or provide concise identification if other format used.",
"type": "string",
"example": "XLSX"
},
"fileFormatVersion": {
"description": "Additional version information for file format used, if required.",
"type": "string",
"example": "2019"
},
"filePart": {
"description": "Pointer to a specific part of a file, where required for disambiguation. For a spreadsheet file, this could be the name of the sheet used.",
"type": "string",
"example": "GothamClay"
},
"fileURI": {
"description": "URI-reference for the data file. This will be a relative link if file is included as part of the AGSi package. Alternatively, a link to a location within a project document system. Spaces are not permitted in URI-reference strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.",
"type": "string",
"format": "uri-reference",
"example": "data/geology/legacydata.xlsx"
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some remarks if required"
},
"revision": {
"description": "Revision of the referenced file.",
"type": "string",
"example": "P3"
},
"revisionInfo": {
"description": "Revision notes for this revision of the referenced file.",
"type": "string",
"example": "Minor corrections, updated for GIR rev P2."
}
},
"additionalProperties": false
}Fields
data_id: Option<String>Identifier for this data object. May be local to this file but all identifiers used within the Data group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.
date: Option<String>Date of issue of this revision.
description: Option<String>Short description of data file defined here.
file_format: Option<String>Format/encoding of the data, i.e. file format. Refer to 9.2. Vocabulary for list of common formats that may be used, or provide concise identification if other format used.
file_format_version: Option<String>Additional version information for file format used, if required.
file_part: Option<String>Pointer to a specific part of a file, where required for disambiguation. For a spreadsheet file, this could be the name of the sheet used.
file_uri: StringURI-reference for the data file. This will be a relative link if file is included as part of the AGSi package. Alternatively, a link to a location within a project document system. Spaces are not permitted in URI-reference strings. Refer to 1.6.6. URI for how to handle spaces in file paths or names.
remarks: Option<String>Additional remarks, if required.
revision: Option<String>Revision of the referenced file.
revision_info: Option<String>Revision notes for this revision of the referenced file.
Implementations
Sourceimpl AgsiDataPropertyFromFile
impl AgsiDataPropertyFromFile
pub fn builder() -> AgsiDataPropertyFromFile