pub struct AgsiDataPropertySummary {
pub case_id: Option<String>,
pub code_id: AgsiDataPropertySummaryCodeId,
pub data_id: Option<String>,
pub remarks: Option<String>,
pub value_count: Option<f64>,
pub value_max: Option<f64>,
pub value_mean: Option<f64>,
pub value_min: Option<f64>,
pub value_std_dev: Option<f64>,
pub value_summary_text: Option<String>,
}Expand description
Each agsiDataPropertySummary object provides a summary of data for a single defined property. Refer to 7.2. Data rules and conventions for further details.
JSON schema
{
"description": "Each agsiDataPropertySummary object provides a summary of data for a single defined property. Refer to 7.2. Data rules and conventions for further details.",
"type": "object",
"required": [
"codeID"
],
"properties": {
"caseID": {
"description": "Code (or text) that identifies the use case for a property. See 7.2.4. Use of (data) case for example use cases. If the input is a code, this shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. May be left blank or omitted, but the combination of codeID and caseID shall be unique for the instances of this object contained within a single parent object instance.",
"type": "string",
"example": "Clay"
},
"codeID": {
"description": "Code that identifies the property. Codes should be defined in either an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. The codes used by the instances of this object contained within a single parent object instance shall be unique, except that if caseID is used then only the combination of codeID and caseID needs to be unique.",
"type": "string",
"minLength": 1,
"example": "TRIG_CU"
},
"dataID": {
"description": "Identifier for this data object. May be local to this file but all identifiers used within the Data group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.",
"type": "string",
"example": "42f18976-7352-4f67-9a6e-df89788343a7"
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some remarks if required"
},
"valueCount": {
"description": "Number of results.",
"type": "number",
"example": 58
},
"valueMax": {
"description": "Maximum value.",
"type": "number",
"example": 345
},
"valueMean": {
"description": "Mean value.",
"type": "number",
"example": 178.2
},
"valueMin": {
"description": "Minimum value.",
"type": "number",
"example": 78
},
"valueStdDev": {
"description": "Standard deviation.",
"type": "number",
"example": 36.4
},
"valueSummaryText": {
"description": "Alternative text based summary, if required or preferred. May be needed when some or all values are not numeric, e.g. <0.001.",
"type": "string",
"example": "<0.01 to 12.57, mean 3.21, (16 results)"
}
},
"additionalProperties": false
}Fields
case_id: Option<String>Code (or text) that identifies the use case for a property. See 7.2.4. Use of (data) case for example use cases. If the input is a code, this shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. May be left blank or omitted, but the combination of codeID and caseID shall be unique for the instances of this object contained within a single parent object instance.
code_id: AgsiDataPropertySummaryCodeIdCode that identifies the property. Codes should be defined in either an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. The codes used by the instances of this object contained within a single parent object instance shall be unique, except that if caseID is used then only the combination of codeID and caseID needs to be unique.
data_id: Option<String>Identifier for this data object. May be local to this file but all identifiers used within the Data group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.
remarks: Option<String>Additional remarks, if required.
value_count: Option<f64>value_max: Option<f64>value_mean: Option<f64>value_min: Option<f64>value_std_dev: Option<f64>value_summary_text: Option<String>Alternative text based summary, if required or preferred. May be needed when some or all values are not numeric, e.g. <0.001.
Implementations
Sourceimpl AgsiDataPropertySummary
impl AgsiDataPropertySummary
pub fn builder() -> AgsiDataPropertySummary