pub struct AgsiDataPropertyValue {
pub case_id: Option<String>,
pub code_id: AgsiDataPropertyValueCodeId,
pub data_id: Option<String>,
pub remarks: Option<String>,
pub value_numeric: Option<f64>,
pub value_profile: Option<ValueProfile>,
pub value_profile_ind_var_code_id: Option<String>,
pub value_text: Option<String>,
}Expand description
Each agsiDataPropertyValue object provides the data for a single defined property. The property value conveyed may be numeric, a profile of numeric values (e.g. a design line) or text. Refer to 7.2. Data rules and conventions for further details.
JSON schema
{
"description": "Each agsiDataPropertyValue object provides the data for a single defined property. The property value conveyed may be numeric, a profile of numeric values (e.g. a design line) or text. Refer to 7.2. Data rules and conventions for further details.",
"type": "object",
"required": [
"codeID"
],
"properties": {
"caseID": {
"description": "Code (or text) that identifies the use case for a property. See 7.2.4. Use of (data) case for example use cases. If the input is a code, this shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. May be left blank or omitted, but the combination of codeID and caseID shall be unique for the instances of this object contained within a single parent object instance.",
"type": "string",
"example": "Clay"
},
"codeID": {
"description": "Code that identifies the property. Codes should be defined in either an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. The codes used by the instances of this object contained within a single parent object instance shall be unique, except that if caseID is used then only the combination of codeID and caseID needs to be unique.",
"type": "string",
"minLength": 1,
"example": "TRIG_CU"
},
"dataID": {
"description": "Identifier for this data object. May be local to this file but all identifiers used within the Data group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.",
"type": "string",
"example": "42f18976-7352-4f67-9a6e-df89788343a7"
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some remarks if required"
},
"valueNumeric": {
"description": "Numeric value of a single property.",
"type": "number",
"example": 120
},
"valueProfile": {
"description": "A profile of values as an ordered list of tuples of [independent variable value, property value]. Typically used to provide properties at different elevations. Refer to 1.6.9. Profiles or arrays of coordinate tuples for further information.",
"type": "array",
"$ref": "#/$defs/valueProfile",
"example": [
[
15.5,
60.0
],
[
14.0,
75.0
],
[
12.5,
105.0
]
]
},
"valueProfileIndVarCodeID": {
"description": "Code that identifies the independent variable for a profile, i.e. what the property value varies against. The code shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object.",
"type": "string",
"example": "Elevation"
},
"valueText": {
"description": "Text value for property, if applicable.",
"type": "string",
"example": "Dry"
}
},
"additionalProperties": false
}Fields
case_id: Option<String>Code (or text) that identifies the use case for a property. See 7.2.4. Use of (data) case for example use cases. If the input is a code, this shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. May be left blank or omitted, but the combination of codeID and caseID shall be unique for the instances of this object contained within a single parent object instance.
code_id: AgsiDataPropertyValueCodeIdCode that identifies the property. Codes should be defined in either an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object. The codes used by the instances of this object contained within a single parent object instance shall be unique, except that if caseID is used then only the combination of codeID and caseID needs to be unique.
data_id: Option<String>Identifier for this data object. May be local to this file but all identifiers used within the Data group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.
remarks: Option<String>Additional remarks, if required.
value_numeric: Option<f64>value_profile: Option<ValueProfile>A profile of values as an ordered list of tuples of [independent variable value, property value]. Typically used to provide properties at different elevations. Refer to 1.6.9. Profiles or arrays of coordinate tuples for further information.
value_profile_ind_var_code_id: Option<String>Code that identifies the independent variable for a profile, i.e. what the property value varies against. The code shall be defined in an agsProjectCode object, or in the code dictionary defined in the relevant agsProjectCodeSet object.
value_text: Option<String>Text value for property, if applicable.
Implementations
Sourceimpl AgsiDataPropertyValue
impl AgsiDataPropertyValue
pub fn builder() -> AgsiDataPropertyValue