pub struct AgsiGeometryPlane {
pub description: Option<String>,
pub elevation: f64,
pub geometry_id: Option<String>,
pub remarks: Option<String>,
}Expand description
An agsiGeometryPlane object is an infinite horizontal plane at a specified elevation.
JSON schema
{
"description": "An agsiGeometryPlane object is an infinite horizontal plane at a specified elevation.",
"type": "object",
"required": [
"elevation"
],
"properties": {
"description": {
"description": "Short description of geometry defined here.",
"type": "string",
"example": "Base of design model"
},
"elevation": {
"description": "Elevation (z) of the plane.",
"type": "number",
"example": -30
},
"geometryID": {
"description": "Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.",
"type": "string",
"example": "DesignBase"
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some remarks if required"
}
},
"additionalProperties": false
}Fields
description: Option<String>Short description of geometry defined here.
elevation: f64geometry_id: Option<String>Identifier for this geometry object. May be local to this file but all identifiers used within the Geometry group of objects shall be unique. Alternatively a UUID may be used (recommended for large datasets). Use of this attribute is optional and it is not referenced anywhere else in the schema, but it may be beneficial to include it to help with data control and integrity, and some applications may require or benefit from it.
remarks: Option<String>Additional remarks, if required.
Implementations
Sourceimpl AgsiGeometryPlane
impl AgsiGeometryPlane
pub fn builder() -> AgsiGeometryPlane