pub struct AgsiModelAlignment {
pub agsi_geometry: Option<AgsiGeometryFromFile>,
pub alignment_id: Option<String>,
pub alignment_name: Option<String>,
pub description: Option<String>,
pub remarks: Option<String>,
pub start_chainage: Option<f64>,
}Expand description
An alignment comprises the geometry and metadata defining a line of interest, most commonly used for the line of a section (cross section, fence or profile - see Guidance for discussion of terminology). Alignments are typically included in a primary 3D model (alternatively a 2D map) but the sections themselves are normally defined as separate models because each 2D section will have its own coordinate system. The alignmentID attribute can be referenced by section models to provide a link to the alignment defined here. Sections must be drawn in the vertical (Z) plane, with alignments defined in the XY plane. The geometry is specified using an embedded agsiGeometryFromFile object referencing an external file.
JSON schema
{
"description": "An alignment comprises the geometry and metadata defining a line of interest, most commonly used for the line of a section (cross section, fence or profile - see Guidance for discussion of terminology). Alignments are typically included in a primary 3D model (alternatively a 2D map) but the sections themselves are normally defined as separate models because each 2D section will have its own coordinate system. The alignmentID attribute can be referenced by section models to provide a link to the alignment defined here. Sections must be drawn in the vertical (Z) plane, with alignments defined in the XY plane. The geometry is specified using an embedded agsiGeometryFromFile object referencing an external file.",
"type": "object",
"properties": {
"agsiGeometry": {
"description": "An embedded Geometry group object defining the geometry of the alignment as a 2D line in XY space. This will be an embedded agsiGeometryFromFile object pointing to a line defined in an external file.",
"type": "object",
"$ref": "#/$defs/agsiGeometryFromFile"
},
"alignmentID": {
"description": "Identifier for the alignment. May be local to this file or a UUID as required/specified. May be referenced by alignmentID attribute of (a different) agsiModel object. Identifiers for alignmentID shall be unique within the AGSi file.",
"type": "string",
"example": "sectionAA"
},
"alignmentName": {
"description": "Name or short description of what this alignment represents.",
"type": "string",
"example": "Section AA"
},
"description": {
"description": "More verbose description, as required.",
"type": "string",
"example": "East-west section through site"
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some additional remarks"
},
"startChainage": {
"description": "The section chainage/baseline distance for the first point defined on the alignment. Assumed to be zero if not used.",
"type": "number",
"example": 1000
}
},
"additionalProperties": false
}Fields
agsi_geometry: Option<AgsiGeometryFromFile>An embedded Geometry group object defining the geometry of the alignment as a 2D line in XY space. This will be an embedded agsiGeometryFromFile object pointing to a line defined in an external file.
alignment_id: Option<String>Identifier for the alignment. May be local to this file or a UUID as required/specified. May be referenced by alignmentID attribute of (a different) agsiModel object. Identifiers for alignmentID shall be unique within the AGSi file.
alignment_name: Option<String>Name or short description of what this alignment represents.
description: Option<String>More verbose description, as required.
remarks: Option<String>Additional remarks, if required.
start_chainage: Option<f64>Implementations
Sourceimpl AgsiModelAlignment
impl AgsiModelAlignment
pub fn builder() -> AgsiModelAlignment