pub struct AgsiModelBoundary {
pub agsi_geometry_boundary_xy: Option<AgsiGeometryFromFile>,
pub agsi_geometry_surface_bottom: Option<AgsiGeometryFromFile>,
pub agsi_geometry_surface_top: Option<AgsiGeometryFromFile>,
pub bottom_elevation: Option<f64>,
pub boundary_id: Option<String>,
pub description: Option<String>,
pub max_x: Option<f64>,
pub max_y: Option<f64>,
pub min_x: Option<f64>,
pub min_y: Option<f64>,
pub remarks: Option<String>,
pub top_elevation: Option<f64>,
}Expand description
An agsiModelBoundary object defines the model boundary, i.e. the maximum extent of the model. Any elements or parts of elements lying outside the boundary are deemed to not be part of the model. Only one boundary per agsiModel is permitted. Only plan boundaries with vertical sides are permitted, defined by either limiting coordinates, or a bounding closed polygon. The top and base may be either a flat plane at a defined elevation, or a surface. Top boundary may not be required, depending on nature of model and/or software/application used (to be confirmed in specification).
JSON schema
{
"description": "An agsiModelBoundary object defines the model boundary, i.e. the maximum extent of the model. Any elements or parts of elements lying outside the boundary are deemed to not be part of the model. Only one boundary per agsiModel is permitted. Only plan boundaries with vertical sides are permitted, defined by either limiting coordinates, or a bounding closed polygon. The top and base may be either a flat plane at a defined elevation, or a surface. Top boundary may not be required, depending on nature of model and/or software/application used (to be confirmed in specification). ",
"type": "object",
"properties": {
"agsiGeometryBoundaryXY": {
"description": "Embedded agsiGeometryFromFile object that provides the geometry of the closed polygon defining the plan extent of model, as an alternative to the box boundary. Use with caution as this may not be supported by all software/applications. Confirm use in specification.",
"type": "object",
"$ref": "#/$defs/agsiGeometryFromFile"
},
"agsiGeometrySurfaceBottom": {
"description": "Embedded agsiGeometryFromFile object that defines the base of the model, as an alternative to the box boundary. Use with caution as this may not be supported by all software/applications. Confirm use in specification.",
"type": "object",
"$ref": "#/$defs/agsiGeometryFromFile"
},
"agsiGeometrySurfaceTop": {
"description": "Embedded agsiGeometryFromFile object that defines the top of the model, as an alternative to the box boundary. Use with caution as this may not be supported by all software/applications. May not be required for some software/applications. Confirm use in specification.",
"type": "object",
"$ref": "#/$defs/agsiGeometryFromFile"
},
"bottomElevation": {
"description": "Elevation (Z) of bottom plane of model for box boundary.",
"type": "number",
"example": -40
},
"boundaryID": {
"description": "Identifier for the model boundary. May be local to this file or a UUID as required/specified. This is optional and is not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity, and some software/applications may require it. If used, identifiers for boundaryID should be unique within the AGSi file. ",
"type": "string",
"example": "BoundarySitewide"
},
"description": {
"description": "Short description.",
"type": "string",
"example": "Boundary for Geological Model: sitewide"
},
"maxX": {
"description": "Maximum X for box boundary.",
"type": "number",
"example": 35000
},
"maxY": {
"description": "Maximum Y for box boundary.",
"type": "number",
"example": 15000
},
"minX": {
"description": "Minimum X for box boundary.",
"type": "number",
"example": 20000
},
"minY": {
"description": "Minimum Y for box boundary.",
"type": "number",
"example": 10000
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some additional remarks"
},
"topElevation": {
"description": "Elevation (Z) of top plane of model for box boundary.",
"type": "number",
"example": 40
}
},
"additionalProperties": false
}Fields
agsi_geometry_boundary_xy: Option<AgsiGeometryFromFile>Embedded agsiGeometryFromFile object that provides the geometry of the closed polygon defining the plan extent of model, as an alternative to the box boundary. Use with caution as this may not be supported by all software/applications. Confirm use in specification.
agsi_geometry_surface_bottom: Option<AgsiGeometryFromFile>Embedded agsiGeometryFromFile object that defines the base of the model, as an alternative to the box boundary. Use with caution as this may not be supported by all software/applications. Confirm use in specification.
agsi_geometry_surface_top: Option<AgsiGeometryFromFile>Embedded agsiGeometryFromFile object that defines the top of the model, as an alternative to the box boundary. Use with caution as this may not be supported by all software/applications. May not be required for some software/applications. Confirm use in specification.
bottom_elevation: Option<f64>boundary_id: Option<String>Identifier for the model boundary. May be local to this file or a UUID as required/specified. This is optional and is not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity, and some software/applications may require it. If used, identifiers for boundaryID should be unique within the AGSi file.
description: Option<String>Short description.
max_x: Option<f64>max_y: Option<f64>min_x: Option<f64>min_y: Option<f64>remarks: Option<String>Additional remarks, if required.
top_elevation: Option<f64>Implementations
Sourceimpl AgsiModelBoundary
impl AgsiModelBoundary
pub fn builder() -> AgsiModelBoundary