pub struct AgsiObservationShape {
pub agsi_data_property_from_file: Option<AgsiDataPropertyFromFile>,
pub agsi_data_property_value: Vec<AgsiDataPropertyValue>,
pub agsi_geometry_from_file: AgsiGeometryFromFile,
pub date: Option<NaiveDate>,
pub made_by: Option<String>,
pub observation_id: Option<String>,
pub observation_nature: Option<String>,
pub observation_text: Option<String>,
pub remarks: Option<String>,
}Expand description
An agsiObservationShape is an observation related to a geographic shape, e.g. line, area, volume or series of points, defined in 2D or 3D space as required. Observations can be text or numeric value(s). Alternatively, a single agsiObservationPoint object can be used to provide attributed data using embedded agsiDataPropertyValue objects. For observations that relate to a line, area, volume or series of points, use agsiObservationShape. For GI exploratory holes and their data, use agsiObservationExpHole.
JSON schema
{
"description": "An agsiObservationShape is an observation related to a geographic shape, e.g. line, area, volume or series of points, defined in 2D or 3D space as required. Observations can be text or numeric value(s). Alternatively, a single agsiObservationPoint object can be used to provide attributed data using embedded agsiDataPropertyValue objects. For observations that relate to a line, area, volume or series of points, use agsiObservationShape. For GI exploratory holes and their data, use agsiObservationExpHole.",
"type": "object",
"required": [
"agsiGeometryFromFile"
],
"properties": {
"agsiDataPropertyFromFile": {
"description": "An embedded agsiDataPropertyFromFile object, which may be used to reference to an external supporting data file.",
"type": "object",
"$ref": "#/$defs/agsiDataPropertyFromFile"
},
"agsiDataPropertyValue": {
"description": "Array of embedded agsiDataPropertyValue objects. May be used to provide attributed data for this observation (numeric values and/or text).",
"type": "array",
"items": {
"$ref": "#/$defs/agsiDataPropertyValue"
}
},
"agsiGeometryFromFile": {
"description": "An embedded Geometry object defining the geometry for this observation, or the location of the observation, which will be a reference to an external file. The geometry may comprise: line, area, volume (or sets therefore), or a set of points.",
"type": "object",
"$ref": "#/$defs/agsiGeometryFromFile"
},
"date": {
"description": "Date of observation, if applicable.",
"type": "string",
"format": "date",
"example": "2018-03-13"
},
"madeBy": {
"description": "Name and/or organisation of person(s) making the observation, if applicable.",
"type": "string",
"example": "S Jones (ABC Consultants)"
},
"observationID": {
"description": "Identifier for this observation. May be local to this file or a UUID as required/specified. This is optional and not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity, and some software/applications may require it. If used, identifiers for observationID should be unique at least within each observation set (agsiObservationSet object), and preferably unique within the AGSi file. ",
"type": "string",
"example": "FieldGeology/Obs/001"
},
"observationNature": {
"description": "Description of the nature of the observation (use observationText for the observation itself).",
"type": "string",
"example": "Geological field survey of visible outcrop"
},
"observationText": {
"description": "Description of the observation as text. Not required if agsiDataPropertyValue used to provide attributed data.",
"type": "string",
"example": "Surveyed boundary of top of Gotham Clay, in side of exposed cutting."
},
"remarks": {
"description": "Additional remarks, if required.",
"type": "string",
"example": "Some remarks if required"
}
},
"additionalProperties": false
}Fields
agsi_data_property_from_file: Option<AgsiDataPropertyFromFile>An embedded agsiDataPropertyFromFile object, which may be used to reference to an external supporting data file.
agsi_data_property_value: Vec<AgsiDataPropertyValue>Array of embedded agsiDataPropertyValue objects. May be used to provide attributed data for this observation (numeric values and/or text).
agsi_geometry_from_file: AgsiGeometryFromFileAn embedded Geometry object defining the geometry for this observation, or the location of the observation, which will be a reference to an external file. The geometry may comprise: line, area, volume (or sets therefore), or a set of points.
date: Option<NaiveDate>Date of observation, if applicable.
made_by: Option<String>Name and/or organisation of person(s) making the observation, if applicable.
observation_id: Option<String>Identifier for this observation. May be local to this file or a UUID as required/specified. This is optional and not referenced anywhere else in the schema, but it may be beneficial to include this to help with data control and integrity, and some software/applications may require it. If used, identifiers for observationID should be unique at least within each observation set (agsiObservationSet object), and preferably unique within the AGSi file.
observation_nature: Option<String>Description of the nature of the observation (use observationText for the observation itself).
observation_text: Option<String>Description of the observation as text. Not required if agsiDataPropertyValue used to provide attributed data.
remarks: Option<String>Additional remarks, if required.
Implementations
Sourceimpl AgsiObservationShape
impl AgsiObservationShape
pub fn builder() -> AgsiObservationShape